@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponse.h 2290 2006-12-22 13:41:02Z svn $
+ * $Id: ApacheResponse.h 2290M 2007-03-24 14:28:33Z (ローカル) $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_H
@@ -144,6 +144,10 @@ public:
     {
         ap_set_last_modified(r);
     };
+    static void set_content_type(Handle *r)
+    {
+        ap_run_type_checker(r);
+    };
     static void set_content_type(Handle *r, const char *content_type)
     {
         ap_set_content_type(r, content_type);
